NamedFileBuilder

Struct NamedFileBuilder 

pub struct NamedFileBuilder { /* private fields */ }
Builder for build NamedFile.

Implementations

Source

impl NamedFileBuilder

pub fn new(path: impl Into<PathBuf>) -> Self

Create a new StaticFile.

pub fn attached_name<T: Into<String>>(self, attached_name: T) -> Self

Sets attached filename and returns Self.

pub fn disposition_type<T: Into<String>>(self, disposition_type: T) -> Self

Sets disposition encoding and returns Self.

pub fn disable_content_disposition(&mut self)

Disable Content-Disposition header.

By default Content-Disposition` header is enabled.

pub fn content_type<T: Into<Mime>>(self, content_type: T) -> Self

Sets content type and returns Self.

pub fn content_encoding<T: Into<String>>(self, content_encoding: T) -> Self

Sets content encoding and returns Self.

pub fn buffer_size(self, buffer_size: u64) -> Self

Sets buffer size and returns Self. During the file chunk read, the maximum read size at one time will affect the access experience and the demand for server memory.

Please set it according to your own situation.

The default is 1M.

pub fn use_etag(self, value: bool) -> Self

Specifies whether to use ETag or not.

Default is true.

pub fn use_last_modified(self, value: bool) -> Self

Specifies whether to use Last-Modified or not.

Default is true.

pub async fn send(self, req_headers: &HeaderMap) -> Builder

Build a new NamedFile and send it.

pub async fn build(self) -> Result<NamedFile>

Build a new NamedFile.